==> ansible-10.4.0.tgz: lib/python3.11/site-packages/ansible_collections/fortinet/fortimanager/plugins/modules/fmgr_filefilter_profile.py <==
#!/usr/bin/python
from __future__ import absolute_import, division, print_function
# Copyright 2019-2024 Fortinet, Inc.
# GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)

__metaclass__ = type

ANSIBLE_METADATA = {'status': ['preview'],
                    'supported_by': 'community',
                    'metadata_version': '1.1'}

DOCUMENTATION = '''
---
module: fmgr_filefilter_profile
short_description: Configure file-filter profiles.
description:
    - This module is able to configure a FortiManager device.
    - Examples include all parameters and values which need to be adjusted to data sources before usage.

version_added: "2.1.0"
author:
    - Xinwei Du (@dux-fortinet)
    - Xing Li (@lix-fortinet)
    - Jie Xue (@JieX19)
    - Link Zheng (@chillancezen)
    - Frank Shen (@fshen01)
    - Hongbin Lu (@fgtdev-hblu)
notes:
    - Starting in version 2.4.0, all input arguments are named using the underscore naming convention (snake_case).
      Please change the arguments such as "var-name" to "var_name".
      Old argument names are still available yet you will receive deprecation warnings.
      You can ignore this warning by setting deprecation_warnings=False in ansible.cfg.
    - Running in workspace locking mode is supported in this FortiManager module, the top
      level parameters workspace_locking_adom and workspace_locking_timeout help do the work.
    - To create or update an object, use state present directive.
    - To delete an object, use state absent directive.
    - Normally, running one module can fail when a non-zero rc is returned. you can also override
      the conditions to fail or succeed with parameters rc_failed and rc_succeeded
options:
    access_token:
        description: The token to access FortiManager without using username and password.
        type: str
    bypass_validation:
        description: Only set to True when module schema diffs with FortiManager API structure, module continues to execute without validating parameters.
        type: bool
        default: false
    enable_log:
        description: Enable/Disable logging for task.
        type: bool
        default: false
    forticloud_access_token:
        description: Authenticate Ansible client with forticloud API access token.
        type: str
    proposed_method:
        description: The overridden method for the underlying Json RPC request.
        type: str
        choices:
          - update
          - set
          - add
    rc_succeeded:
        description: The rc codes list with which the conditions to succeed will be overriden.
        type: list
        elements: int
    rc_failed:
        description: The rc codes list with which the conditions to fail will be overriden.
        type: list
        elements: int
    state:
        description: The directive to create, update or delete an object.
        type: str
        required: true
        choices:
          - present
          - absent
    workspace_locking_adom:
        description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
        type: str
    workspace_locking_timeout:
        description: The maximum time in seconds to wait for other user to release the workspace lock.
        type: int
        default: 300
    adom:
        description: The parameter (adom) in requested url.
        type: str
        required: true
    filefilter_profile:
        description: The top level parameters set.
        required: false
        type: dict
        suboptions:
            comment:
                type: str
                description: Comment.
            extended-log:
                type: str
                description: Deprecated, please rename it to extended_log. Enable/disable file-filter extended logging.
                choices:
                    - 'disable'
                    - 'enable'
            feature-set:
                type: str
                description: Deprecated, please rename it to feature_set. Flow/proxy feature set.
                choices:
                    - 'proxy'
                    - 'flow'
            log:
                type: str
                description: Enable/disable file-filter logging.
                choices:
                    - 'disable'
                    - 'enable'
            name:
                type: str
                description: Profile name.
                required: true
            replacemsg-group:
                type: str
                description: Deprecated, please rename it to replacemsg_group. Replacement message group
            rules:
                type: list
                elements: dict
                description: Rules.
                suboptions:
                    action:
                        type: str
                        description: Action taken for matched file.
                        choices:
                            - 'log-only'
                            - 'block'
                    comment:
                        type: str
                        description: Comment.
                    direction:
                        type: str
                        description: Traffic direction.
                        choices:
                            - 'any'
                            - 'incoming'
                            - 'outgoing'
                    file-type:
                        type: raw
                        description: (list) Deprecated, please rename it to file_type. Select file type.
                    name:
                        type: str
                        description: File-filter rule name.
                    password-protected:
                        type: str
                        description: Deprecated, please rename it to password_protected. Match password-protected files.
                        choices:
                            - 'any'
                            - 'yes'
                    protocol:
                        type: list
                        elements: str
                        description: Protocols to apply rule to.
                        choices:
                            - 'imap'
                            - 'smtp'
                            - 'pop3'
                            - 'http'
                            - 'ftp'
                            - 'mapi'
                            - 'cifs'
                            - 'ssh'
            scan-archive-contents:
                type: str
                description: Deprecated, please rename it to scan_archive_contents. Enable/disable archive contents scan.
                choices:
                    - 'disable'
                    - 'enable'
'''

EXAMPLES = '''
- name: Example playbook (generated based on argument schema)
  hosts: fortimanagers
  connection: httpapi
  vars:
    ansible_httpapi_use_ssl: true
    ansible_httpapi_validate_certs: false
    ansible_httpapi_port: 443
  tasks:
    - name: Configure file-filter profiles.
      fortinet.fortimanager.fmgr_filefilter_profile:
        # bypass_validation: false
        workspace_locking_adom: <value in [global, custom adom including root]>
        workspace_locking_timeout: 300
        # rc_succeeded: [0, -2, -3, ...]
        # rc_failed: [-2, -3, ...]
        adom: <your own value>
        state: present # <value in [present, absent]>
        filefilter_profile:
          comment: <string>
          extended_log: <value in [disable, enable]>
          feature_set: <value in [proxy, flow]>
          log: <value in [disable, enable]>
          name: <string>
          replacemsg_group: <string>
          rules:
            -
              action: <value in [log-only, block]>
              comment: <string>
              direction: <value in [any, incoming, outgoing]>
              file_type: <list or string>
              name: <string>
              password_protected: <value in [any, yes]>
              protocol:
                - imap
                - smtp
                - pop3
                - http
                - ftp
                - mapi
                - cifs
                - ssh
          scan_archive_contents: <value in [disable, enable]>
'''

RETURN = '''
meta:
    description: The result of the request.
    type: dict
    returned: always
    contains:
        request_url:
            description: The full url requested.
            returned: always
            type: str
            sample: /sys/login/user
        response_code:
            description: The status of api request.
            returned: always
            type: int
            sample: 0
        response_data:
            description: The api response.
            type: list
            returned: always
        response_message:
            description: The descriptive message of the api response.
            type: str
            returned: always
            sample: OK.
        system_information:
            description: The information of the target system.
            type: dict
            returned: always
rc:
    description: The status the request.
    type: int
    returned: always
    sample: 0
version_check_warning:
    description: Warning if the parameters used in the playbook are not supported by the current FortiManager version.
    type: list
    returned: complex
'''
from ansible.module_utils.basic import AnsibleModule
from ansible.module_utils.connection import Connection
from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec


def main():
    jrpc_urls = [
        '/pm/config/adom/{adom}/obj/file-filter/profile',
        '/pm/config/global/obj/file-filter/profile'
    ]

    perobject_jrpc_urls = [
        '/pm/config/adom/{adom}/obj/file-filter/profile/{profile}',
        '/pm/config/global/obj/file-filter/profile/{profile}'
    ]

    url_params = ['adom']
    module_primary_key = 'name'
    module_arg_spec = {
        'adom': {'required': True, 'type': 'str'},
        'filefilter_profile': {
            'type': 'dict',
            'v_range': [['6.4.1', '']],
            'options': {
                'comment': {'v_range': [['6.4.1', '']], 'type': 'str'},
                'extended-log': {'v_range': [['6.4.2', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
                'feature-set': {'v_range': [['6.4.1', '']], 'choices': ['proxy', 'flow'], 'type': 'str'},
                'log': {'v_range': [['6.4.1', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
                'name': {'v_range': [['6.4.1', '']], 'required': True, 'type': 'str'},
                'replacemsg-group': {'v_range': [['6.4.1', '']], 'type': 'str'},
                'rules': {
                    'v_range': [['6.4.1', '']],
                    'type': 'list',
                    'options': {
                        'action': {'v_range': [['6.4.1', '']], 'choices': ['log-only', 'block'], 'type': 'str'},
                        'comment': {'v_range': [['6.4.1', '']], 'type': 'str'},
                        'direction': {'v_range': [['6.4.1', '']], 'choices': ['any', 'incoming', 'outgoing'], 'type': 'str'},
                        'file-type': {'v_range': [['6.4.1', '']], 'type': 'raw'},
                        'name': {'v_range': [['6.4.1', '']], 'type': 'str'},
                        'password-protected': {'v_range': [['6.4.1', '']], 'choices': ['any', 'yes'], 'type': 'str'},
                        'protocol': {
                            'v_range': [['6.4.1', '']],
                            'type': 'list',
                            'choices': ['imap', 'smtp', 'pop3', 'http', 'ftp', 'mapi', 'cifs', 'ssh'],
                            'elements': 'str'
                        }
                    },
                    'elements': 'dict'
                },
                'scan-archive-contents': {'v_range': [['6.4.1', '']], 'choices': ['disable', 'enable'], 'type': 'str'}
            }

        }
    }

    module_option_spec = get_module_arg_spec('full crud')
    module_arg_spec.update(module_option_spec)
    params_validation_blob = []
    check_galaxy_version(module_arg_spec)
    module = AnsibleModule(argument_spec=check_parameter_bypass(module_arg_spec, 'filefilter_profile'),
                           supports_check_mode=True)

    if not module._socket_path:
        module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
    connection = Connection(module._socket_path)
    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
    fmgr.validate_parameters(params_validation_blob)
    fmgr.process_curd(argument_specs=module_arg_spec)

    module.exit_json(meta=module.params)


if __name__ == '__main__':
    main()

==> ansible-11.4.0.tgz: lib/python3.12/site-packages/ansible_collections/fortinet/fortimanager/plugins/modules/fmgr_filefilter_profile.py <==
#!/usr/bin/python
from __future__ import absolute_import, division, print_function
# Copyright 2019-2024 Fortinet, Inc.
# GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)

__metaclass__ = type

ANSIBLE_METADATA = {'status': ['preview'],
                    'supported_by': 'community',
                    'metadata_version': '1.1'}

DOCUMENTATION = '''
---
module: fmgr_filefilter_profile
short_description: Configure file-filter profiles.
description:
    - This module is able to configure a FortiManager device.
    - Examples include all parameters and values which need to be adjusted to data sources before usage.

version_added: "2.1.0"
author:
    - Xinwei Du (@dux-fortinet)
    - Xing Li (@lix-fortinet)
    - Jie Xue (@JieX19)
    - Link Zheng (@chillancezen)
    - Frank Shen (@fshen01)
    - Hongbin Lu (@fgtdev-hblu)
notes:
    - Starting in version 2.4.0, all input arguments are named using the underscore naming convention (snake_case).
      Please change the arguments such as "var-name" to "var_name".
      Old argument names are still available yet you will receive deprecation warnings.
      You can ignore this warning by setting deprecation_warnings=False in ansible.cfg.
    - Running in workspace locking mode is supported in this FortiManager module, the top
      level parameters workspace_locking_adom and workspace_locking_timeout help do the work.
    - To create or update an object, use state present directive.
    - To delete an object, use state absent directive.
    - Normally, running one module can fail when a non-zero rc is returned. you can also override
      the conditions to fail or succeed with parameters rc_failed and rc_succeeded
options:
    access_token:
        description: The token to access FortiManager without using username and password.
        type: str
    bypass_validation:
        description: Only set to True when module schema diffs with FortiManager API structure, module continues to execute without validating parameters.
        type: bool
        default: false
    enable_log:
        description: Enable/Disable logging for task.
        type: bool
        default: false
    forticloud_access_token:
        description: Authenticate Ansible client with forticloud API access token.
        type: str
    proposed_method:
        description: The overridden method for the underlying Json RPC request.
        type: str
        choices:
          - update
          - set
          - add
    rc_succeeded:
        description: The rc codes list with which the conditions to succeed will be overriden.
        type: list
        elements: int
    rc_failed:
        description: The rc codes list with which the conditions to fail will be overriden.
        type: list
        elements: int
    state:
        description: The directive to create, update or delete an object.
        type: str
        required: true
        choices:
          - present
          - absent
    workspace_locking_adom:
        description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
        type: str
    workspace_locking_timeout:
        description: The maximum time in seconds to wait for other user to release the workspace lock.
        type: int
        default: 300
    adom:
        description: The parameter (adom) in requested url.
        type: str
        required: true
    filefilter_profile:
        description: The top level parameters set.
        required: false
        type: dict
        suboptions:
            comment:
                type: str
                description: Comment.
            extended_log:
                aliases: ['extended-log']
                type: str
                description: Enable/disable file-filter extended logging.
                choices:
                    - 'disable'
                    - 'enable'
            feature_set:
                aliases: ['feature-set']
                type: str
                description: Flow/proxy feature set.
                choices:
                    - 'proxy'
                    - 'flow'
            log:
                type: str
                description: Enable/disable file-filter logging.
                choices:
                    - 'disable'
                    - 'enable'
            name:
                type: str
                description: Profile name.
                required: true
            replacemsg_group:
                aliases: ['replacemsg-group']
                type: str
                description: Replacement message group
            rules:
                type: list
                elements: dict
                description: Rules.
                suboptions:
                    action:
                        type: str
                        description: Action taken for matched file.
                        choices:
                            - 'log-only'
                            - 'block'
                    comment:
                        type: str
                        description: Comment.
                    direction:
                        type: str
                        description: Traffic direction.
                        choices:
                            - 'any'
                            - 'incoming'
                            - 'outgoing'
                    file_type:
                        aliases: ['file-type']
                        type: raw
                        description: (list) Select file type.
                    name:
                        type: str
                        description: File-filter rule name.
                    password_protected:
                        aliases: ['password-protected']
                        type: str
                        description: Match password-protected files.
                        choices:
                            - 'any'
                            - 'yes'
                    protocol:
                        type: list
                        elements: str
                        description: Protocols to apply rule to.
                        choices:
                            - 'imap'
                            - 'smtp'
                            - 'pop3'
                            - 'http'
                            - 'ftp'
                            - 'mapi'
                            - 'cifs'
                            - 'ssh'
            scan_archive_contents:
                aliases: ['scan-archive-contents']
                type: str
                description: Enable/disable archive contents scan.
                choices:
                    - 'disable'
                    - 'enable'
'''

EXAMPLES = '''
- name: Example playbook (generated based on argument schema)
  hosts: fortimanagers
  connection: httpapi
  vars:
    ansible_httpapi_use_ssl: true
    ansible_httpapi_validate_certs: false
    ansible_httpapi_port: 443
  tasks:
    - name: Configure file-filter profiles.
      fortinet.fortimanager.fmgr_filefilter_profile:
        # bypass_validation: false
        workspace_locking_adom: <value in [global, custom adom including root]>
        workspace_locking_timeout: 300
        # rc_succeeded: [0, -2, -3, ...]
        # rc_failed: [-2, -3, ...]
        adom: <your own value>
        state: present # <value in [present, absent]>
        filefilter_profile:
          name: "your value" # Required variable, string
          # comment: <string>
          # extended_log: <value in [disable, enable]>
          # feature_set: <value in [proxy, flow]>
          # log: <value in [disable, enable]>
          # replacemsg_group: <string>
          # rules:
          #   - action: <value in [log-only, block]>
          #     comment: <string>
          #     direction: <value in [any, incoming, outgoing]>
          #     file_type: <list or string>
          #     name: <string>
          #     password_protected: <value in [any, yes]>
          #     protocol:
          #       - "imap"
          #       - "smtp"
          #       - "pop3"
          #       - "http"
          #       - "ftp"
          #       - "mapi"
          #       - "cifs"
          #       - "ssh"
          # scan_archive_contents: <value in [disable, enable]>
'''

RETURN = '''
meta:
    description: The result of the request.
    type: dict
    returned: always
    contains:
        request_url:
            description: The full url requested.
            returned: always
            type: str
            sample: /sys/login/user
        response_code:
            description: The status of api request.
            returned: always
            type: int
            sample: 0
        response_data:
            description: The api response.
            type: list
            returned: always
        response_message:
            description: The descriptive message of the api response.
            type: str
            returned: always
            sample: OK.
        system_information:
            description: The information of the target system.
            type: dict
            returned: always
rc:
    description: The status the request.
    type: int
    returned: always
    sample: 0
version_check_warning:
    description: Warning if the parameters used in the playbook are not supported by the current FortiManager version.
    type: list
    returned: complex
'''
from ansible.module_utils.basic import AnsibleModule
from ansible.module_utils.connection import Connection
from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec


def main():
    urls_list = [
        '/pm/config/adom/{adom}/obj/file-filter/profile',
        '/pm/config/global/obj/file-filter/profile'
    ]
    url_params = ['adom']
    module_primary_key = 'name'
    module_arg_spec = {
        'adom': {'required': True, 'type': 'str'},
        'filefilter_profile': {
            'type': 'dict',
            'v_range': [['6.4.1', '']],
            'options': {
                'comment': {'v_range': [['6.4.1', '']], 'type': 'str'},
                'extended-log': {'v_range': [['6.4.2', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
                'feature-set': {'v_range': [['6.4.1', '']], 'choices': ['proxy', 'flow'], 'type': 'str'},
                'log': {'v_range': [['6.4.1', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
                'name': {'v_range': [['6.4.1', '']], 'required': True, 'type': 'str'},
                'replacemsg-group': {'v_range': [['6.4.1', '']], 'type': 'str'},
                'rules': {
                    'v_range': [['6.4.1', '']],
                    'type': 'list',
                    'options': {
                        'action': {'v_range': [['6.4.1', '']], 'choices': ['log-only', 'block'], 'type': 'str'},
                        'comment': {'v_range': [['6.4.1', '']], 'type': 'str'},
                        'direction': {'v_range': [['6.4.1', '']], 'choices': ['any', 'incoming', 'outgoing'], 'type': 'str'},
                        'file-type': {'v_range': [['6.4.1', '']], 'type': 'raw'},
                        'name': {'v_range': [['6.4.1', '']], 'type': 'str'},
                        'password-protected': {'v_range': [['6.4.1', '']], 'choices': ['any', 'yes'], 'type': 'str'},
                        'protocol': {
                            'v_range': [['6.4.1', '']],
                            'type': 'list',
                            'choices': ['imap', 'smtp', 'pop3', 'http', 'ftp', 'mapi', 'cifs', 'ssh'],
                            'elements': 'str'
                        }
                    },
                    'elements': 'dict'
                },
                'scan-archive-contents': {'v_range': [['6.4.1', '']], 'choices': ['disable', 'enable'], 'type': 'str'}
            }
        }
    }

    module_option_spec = get_module_arg_spec('full crud')
    module_arg_spec.update(module_option_spec)
    params_validation_blob = []
    check_galaxy_version(module_arg_spec)
    module = AnsibleModule(argument_spec=check_parameter_bypass(module_arg_spec, 'filefilter_profile'),
                           supports_check_mode=True)

    if not module._socket_path:
        module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
    connection = Connection(module._socket_path)
    fmgr = NAPIManager('full crud', module_arg_spec, urls_list, module_primary_key, url_params,
                       module, connection, top_level_schema_name='data')
    fmgr.validate_parameters(params_validation_blob)
    fmgr.process_crud()

    module.exit_json(meta=module.params)


if __name__ == '__main__':
    main()
